Command class

Constructors

Command({required String name, required List<ParameterInfo> params, required ConcurrencyType concurrency, required String dataType, bool isKeepAlive = false})
const

Properties

commandControllerType String
Command controller type - same as notifierType for the new unified CommandNotifier
no setter
concurrency ConcurrencyType
final
dataType String
final
familyParams List<ParameterInfo>
Params marked with @family annotation - used as provider family key
no setter
hasArg bool
no setter
hasFamily bool
no setter
hashCode int
The hash code for this object.
no setterinherited
hasNonFamilyArg bool
no setter
isKeepAlive bool
final
name String
final
nonFamilyParams List<ParameterInfo>
Non-family params - passed to the command's run() method
no setter
notifierType String
CommandNotifier type with data type and arg record type For no-arg commands, argRecordType is () (empty record)
no setter
nullableStateType String
Returns the nullable version of stateType. If stateType already ends with '?', returns it as-is to avoid 'Type??'.
no setter
params List<ParameterInfo>
final
publicName String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stateType String
State type is always ArgCommandState with the appropriate arg record type For no-arg commands, argRecordType is () (empty record)
no setter
strategyType String
no setter

Methods

build() String
builder({required ProviderInfo? parent}) CommandBuilder
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited