CommandBuilder class

Constructors

CommandBuilder({required Command command, required ProviderInfo? parent})
const

Properties

command Command
final
facadeCommandClassName String
no setter
facadeCommandClassNameRef String
no setter
facadeCommandClassNameWidgetRef String
no setter
hashCode int
The hash code for this object.
no setterinherited
parent ProviderInfo?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildCommandClassInsideParent() String
Builds the command class for commands inside parent
buildCommandInsideParent() String
buildFacadeCommandClassRef() String
buildFacadeCommandClassWidgetRef() String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited