FileProcessor class
Handles file processing operations
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
processFileIfChanged(
File file) → Future< void> - Processes file only if it has changed
-
processProviderFile(
String contents, File file) → Future< void> -
registerPlugins(
List< RiverpodCraftPlugin> extraPlugins) → void - Register additional plugins (e.g., community plugins from config).