ProviderInfo class

Constructors

ProviderInfo({required String name, required String dataType, required bool isKeepAlive, required ProviderType type, required List<ParameterInfo> params, required List<Command> commands, bool isFunctional = false, String? functionName, bool requiresRef = false, bool isSettable = false, bool hasPagedMapper = false, List<String> allProviderVarNames = const [], List<PublicMethod> publicMethods = const []})
const

Properties

allProviderVarNames List<String>
final
commands List<Command>
final
dataType String
no setter
facadeClassName String
no setter
functionName String?
final
hasArg bool
no setter
hashCode int
The hash code for this object.
no setterinherited
hasPagedMapper bool
final
isFunctional bool
final
isKeepAlive bool
final
isSettable bool
final
name String
final
notifierType String
no setter
nullableStateType String
Returns the nullable version of stateType. If stateType already ends with '?', returns it as-is to avoid 'Type??'.
no setter
params List<ParameterInfo>
final
providerVarName String
no setter
publicMethods List<PublicMethod>
final
requiresRef bool
final
returnName String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stateType String
no setter
type ProviderType
final

Methods

build() String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited