ProviderDataCollection class
Constructors
-
ProviderDataCollection({required List<
ProviderInfo> providers, required List<Command> commands}) -
const
Properties
-
commands
→ List<
Command> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
providers
→ List<
ProviderInfo> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
) → String? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited